# SPDX-License-Identifier: Apache-2.0
# Copyright (c) 2022 Dell Inc, or its subsidiaries.

import grpc

from .proto.v1 import inventory_pb2


def get_inventory(address):
    print(
        "tbd",
        address,
        grpc.StatusCode.UNIMPLEMENTED,
        inventory_pb2.InventoryGetRequest(),
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_null.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import object_key_pb2 as object__key__pb2
import opicommon_pb2 as opicommon__pb2
import uuid_pb2 as uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x62\x61\x63kend_null.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x10object_key.proto\x1a\x0fopicommon.proto\x1a\nuuid.proto\"\x8a\x01\n\tNullDebug\x12,\n\x06handle\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x12\n\nblock_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x62locks_count\x18\x03 \x01(\x03\x12%\n\x04uuid\x18\x04 \x01(\x0b\x32\x17.opi_api.common.v1.Uuid\"\x9d\x01\n\x16\x43reateNullDebugRequest\x12\x34\n\x06parent\x18\x01 \x01(\tB$\xe0\x41\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/NullDebug\x12\x36\n\nnull_debug\x18\x02 \x01(\x0b\x32\x1d.opi_api.storage.v1.NullDebugB\x03\xe0\x41\x02\x12\x15\n\rnull_debug_id\x18\x03 \x01(\t\"L\n\x16\x44\x65leteNullDebugRequest\x12\x32\n\x04name\x18\x01 \x01(\tB$\xe0\x41\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/NullDebug\"|\n\x16UpdateNullDebugRequest\x12\x31\n\nnull_debug\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.NullDebug\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"t\n\x15ListNullDebugsRequest\x12\x34\n\x06parent\x18\x01 \x01(\tB$\xe0\x41\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/NullDebug\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"e\n\x16ListNullDebugsResponse\x12\x32\n\x0bnull_debugs\x18\x01 \x03(\x0b\x32\x1d.opi_api.storage.v1.NullDebug\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"I\n\x13GetNullDebugRequest\x12\x32\n\x04name\x18\x01 \x01(\tB$\xe0\x41\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/NullDebug\"E\n\x15NullDebugStatsRequest\x12,\n\x06handle\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"v\n\x16NullDebugStatsResponse\x12,\n\x06handle\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats2\x82\x07\n\x10NullDebugService\x12\xab\x01\n\x0f\x43reateNullDebug\x12*.opi_api.storage.v1.CreateNullDebugRequest\x1a\x1d.opi_api.storage.v1.NullDebug\"M\x82\xd3\xe4\x93\x02%\"\x17/v1/{parent=subsystems}:\nnull_debug\xda\x41\x1fparent,null_debug,null_debug_id\x12\x87\x01\n\x0f\x44\x65leteNullDebug\x12*.opi_api.storage.v1.DeleteNullDebugRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02#*!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12\xab\x01\n\x0fUpdateNullDebug\x12*.opi_api.storage.v1.UpdateNullDebugRequest\x1a\x1d.opi_api.storage.v1.NullDebug\"M\x82\xd3\xe4\x93\x02.2 /v1/{null_debug.name=subsystems}:\nnull_debug\xda\x41\x16null_debug,update_mask\x12\x91\x01\n\x0eListNullDebugs\x12).opi_api.storage.v1.ListNullDebugsRequest\x1a*.opi_api.storage.v1.ListNullDebugsResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x88\x01\n\x0cGetNullDebug\x12\'.opi_api.storage.v1.GetNullDebugRequest\x1a\x1d.opi_api.storage.v1.NullDebug\"0\x82\xd3\xe4\x93\x02#\x12!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12i\n\x0eNullDebugStats\x12).opi_api.storage.v1.NullDebugStatsRequest\x1a*.opi_api.storage.v1.NullDebugStatsResponse\"\x00\x42_\n\x12opi_api.storage.v1B\x10\x42\x61\x63kendNullProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')



_NULLDEBUG = DESCRIPTOR.message_types_by_name['NullDebug']
_CREATENULLDEBUGREQUEST = DESCRIPTOR.message_types_by_name['CreateNullDebugRequest']
_DELETENULLDEBUGREQUEST = DESCRIPTOR.message_types_by_name['DeleteNullDebugRequest']
_UPDATENULLDEBUGREQUEST = DESCRIPTOR.message_types_by_name['UpdateNullDebugRequest']
_LISTNULLDEBUGSREQUEST = DESCRIPTOR.message_types_by_name['ListNullDebugsRequest']
_LISTNULLDEBUGSRESPONSE = DESCRIPTOR.message_types_by_name['ListNullDebugsResponse']
_GETNULLDEBUGREQUEST = DESCRIPTOR.message_types_by_name['GetNullDebugRequest']
_NULLDEBUGSTATSREQUEST = DESCRIPTOR.message_types_by_name['NullDebugStatsRequest']
_NULLDEBUGSTATSRESPONSE = DESCRIPTOR.message_types_by_name['NullDebugStatsResponse']
NullDebug = _reflection.GeneratedProtocolMessageType('NullDebug', (_message.Message,), {
  'DESCRIPTOR' : _NULLDEBUG,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NullDebug)
  })
_sym_db.RegisterMessage(NullDebug)

CreateNullDebugRequest = _reflection.GeneratedProtocolMessageType('CreateNullDebugRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENULLDEBUGREQUEST,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateNullDebugRequest)
  })
_sym_db.RegisterMessage(CreateNullDebugRequest)

DeleteNullDebugRequest = _reflection.GeneratedProtocolMessageType('DeleteNullDebugRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENULLDEBUGREQUEST,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteNullDebugRequest)
  })
_sym_db.RegisterMessage(DeleteNullDebugRequest)

UpdateNullDebugRequest = _reflection.GeneratedProtocolMessageType('UpdateNullDebugRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENULLDEBUGREQUEST,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateNullDebugRequest)
  })
_sym_db.RegisterMessage(UpdateNullDebugRequest)

ListNullDebugsRequest = _reflection.GeneratedProtocolMessageType('ListNullDebugsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNULLDEBUGSREQUEST,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNullDebugsRequest)
  })
_sym_db.RegisterMessage(ListNullDebugsRequest)

ListNullDebugsResponse = _reflection.GeneratedProtocolMessageType('ListNullDebugsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNULLDEBUGSRESPONSE,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNullDebugsResponse)
  })
_sym_db.RegisterMessage(ListNullDebugsResponse)

GetNullDebugRequest = _reflection.GeneratedProtocolMessageType('GetNullDebugRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNULLDEBUGREQUEST,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetNullDebugRequest)
  })
_sym_db.RegisterMessage(GetNullDebugRequest)

NullDebugStatsRequest = _reflection.GeneratedProtocolMessageType('NullDebugStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _NULLDEBUGSTATSREQUEST,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NullDebugStatsRequest)
  })
_sym_db.RegisterMessage(NullDebugStatsRequest)

NullDebugStatsResponse = _reflection.GeneratedProtocolMessageType('NullDebugStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _NULLDEBUGSTATSRESPONSE,
  '__module__' : 'backend_null_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NullDebugStatsResponse)
  })
_sym_db.RegisterMessage(NullDebugStatsResponse)

_NULLDEBUGSERVICE = DESCRIPTOR.services_by_name['NullDebugService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\020BackendNullProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _CREATENULLDEBUGREQUEST.fields_by_name['parent']._options = None
  _CREATENULLDEBUGREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\036\n\034opi_api.storage.v1/NullDebug'
  _CREATENULLDEBUGREQUEST.fields_by_name['null_debug']._options = None
  _CREATENULLDEBUGREQUEST.fields_by_name['null_debug']._serialized_options = b'\340A\002'
  _DELETENULLDEBUGREQUEST.fields_by_name['name']._options = None
  _DELETENULLDEBUGREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\036\n\034opi_api.storage.v1/NullDebug'
  _LISTNULLDEBUGSREQUEST.fields_by_name['parent']._options = None
  _LISTNULLDEBUGSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\036\n\034opi_api.storage.v1/NullDebug'
  _GETNULLDEBUGREQUEST.fields_by_name['name']._options = None
  _GETNULLDEBUGREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\036\n\034opi_api.storage.v1/NullDebug'
  _NULLDEBUGSERVICE.methods_by_name['CreateNullDebug']._options = None
  _NULLDEBUGSERVICE.methods_by_name['CreateNullDebug']._serialized_options = b'\202\323\344\223\002%\"\027/v1/{parent=subsystems}:\nnull_debug\332A\037parent,null_debug,null_debug_id'
  _NULLDEBUGSERVICE.methods_by_name['DeleteNullDebug']._options = None
  _NULLDEBUGSERVICE.methods_by_name['DeleteNullDebug']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _NULLDEBUGSERVICE.methods_by_name['UpdateNullDebug']._options = None
  _NULLDEBUGSERVICE.methods_by_name['UpdateNullDebug']._serialized_options = b'\202\323\344\223\002.2 /v1/{null_debug.name=subsystems}:\nnull_debug\332A\026null_debug,update_mask'
  _NULLDEBUGSERVICE.methods_by_name['ListNullDebugs']._options = None
  _NULLDEBUGSERVICE.methods_by_name['ListNullDebugs']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _NULLDEBUGSERVICE.methods_by_name['GetNullDebug']._options = None
  _NULLDEBUGSERVICE.methods_by_name['GetNullDebug']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _NULLDEBUG._serialized_start=268
  _NULLDEBUG._serialized_end=406
  _CREATENULLDEBUGREQUEST._serialized_start=409
  _CREATENULLDEBUGREQUEST._serialized_end=566
  _DELETENULLDEBUGREQUEST._serialized_start=568
  _DELETENULLDEBUGREQUEST._serialized_end=644
  _UPDATENULLDEBUGREQUEST._serialized_start=646
  _UPDATENULLDEBUGREQUEST._serialized_end=770
  _LISTNULLDEBUGSREQUEST._serialized_start=772
  _LISTNULLDEBUGSREQUEST._serialized_end=888
  _LISTNULLDEBUGSRESPONSE._serialized_start=890
  _LISTNULLDEBUGSRESPONSE._serialized_end=991
  _GETNULLDEBUGREQUEST._serialized_start=993
  _GETNULLDEBUGREQUEST._serialized_end=1066
  _NULLDEBUGSTATSREQUEST._serialized_start=1068
  _NULLDEBUGSTATSREQUEST._serialized_end=1137
  _NULLDEBUGSTATSRESPONSE._serialized_start=1139
  _NULLDEBUGSTATSRESPONSE._serialized_end=1257
  _NULLDEBUGSERVICE._serialized_start=1260
  _NULLDEBUGSERVICE._serialized_end=2158
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_nvme_pcie.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x62\x61\x63kend_nvme_pcie.proto\x12\x12opi_api.storage.v1Bc\n\x12opi_api.storage.v1B\x14\x42\x61\x63kendNvmePcieProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')



if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\024BackendNvmePcieProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: inventory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0finventory.proto\x12\x14opi_api.inventory.v1\"9\n\x08\x42IOSInfo\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\"}\n\nSystemInfo\x12\x0e\n\x06\x66\x61mily\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06vendor\x18\x03 \x01(\t\x12\x15\n\rserial_number\x18\x04 \x01(\t\x12\x0c\n\x04uuid\x18\x05 \x01(\t\x12\x0b\n\x03sku\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\"\x80\x01\n\x0b\x43hassisInfo\x12\x11\n\tasset_tag\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x18\n\x10type_description\x18\x04 \x01(\t\x12\x0e\n\x06vendor\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\"k\n\rBaseboardInfo\x12\x11\n\tasset_tag\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x0e\n\x06vendor\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x0f\n\x07product\x18\x05 \x01(\t\"5\n\x07\x43PUInfo\x12\x13\n\x0btotal_cores\x18\x01 \x01(\x05\x12\x15\n\rtotal_threads\x18\x02 \x01(\x05\"F\n\nMemoryInfo\x12\x1c\n\x14total_physical_bytes\x18\x01 \x01(\x03\x12\x1a\n\x12total_usable_bytes\x18\x02 \x01(\x03\"\xbf\x01\n\nDeviceInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08mfg_name\x18\x04 \x01(\t\x12\x10\n\x08mfg_date\x18\x05 \x01(\t\x12\x12\n\nhw_version\x18\x06 \x01(\t\x12\x12\n\nfw_version\x18\x07 \x01(\t\x12\x12\n\nsw_version\x18\x08 \x01(\t\x12\x11\n\tserial_no\x18\t \x01(\t\x12\x0f\n\x07part_no\x18\n \x01(\t\"\x15\n\x13InventoryGetRequest\"\xf9\x02\n\x14InventoryGetResponse\x12,\n\x04\x62ios\x18\x01 \x01(\x0b\x32\x1e.opi_api.inventory.v1.BIOSInfo\x12\x30\n\x06system\x18\x02 \x01(\x0b\x32 .opi_api.inventory.v1.SystemInfo\x12\x36\n\tbaseboard\x18\x03 \x01(\x0b\x32#.opi_api.inventory.v1.BaseboardInfo\x12\x32\n\x07\x63hassis\x18\x04 \x01(\x0b\x32!.opi_api.inventory.v1.ChassisInfo\x12\x30\n\tprocessor\x18\x05 \x01(\x0b\x32\x1d.opi_api.inventory.v1.CPUInfo\x12\x30\n\x06memory\x18\x06 \x01(\x0b\x32 .opi_api.inventory.v1.MemoryInfo\x12\x31\n\x07\x64\x65vinfo\x18\x07 \x01(\x0b\x32 .opi_api.inventory.v1.DeviceInfo2w\n\x0cInventorySvc\x12g\n\x0cInventoryGet\x12).opi_api.inventory.v1.InventoryGetRequest\x1a*.opi_api.inventory.v1.InventoryGetResponse\"\x00\x42X\n\x14opi_api.inventory.v1B\x0eInventoryProtoP\x01Z.github.com/opiproject/opi-api/common/v1/gen/gob\x06proto3')



_BIOSINFO = DESCRIPTOR.message_types_by_name['BIOSInfo']
_SYSTEMINFO = DESCRIPTOR.message_types_by_name['SystemInfo']
_CHASSISINFO = DESCRIPTOR.message_types_by_name['ChassisInfo']
_BASEBOARDINFO = DESCRIPTOR.message_types_by_name['BaseboardInfo']
_CPUINFO = DESCRIPTOR.message_types_by_name['CPUInfo']
_MEMORYINFO = DESCRIPTOR.message_types_by_name['MemoryInfo']
_DEVICEINFO = DESCRIPTOR.message_types_by_name['DeviceInfo']
_INVENTORYGETREQUEST = DESCRIPTOR.message_types_by_name['InventoryGetRequest']
_INVENTORYGETRESPONSE = DESCRIPTOR.message_types_by_name['InventoryGetResponse']
BIOSInfo = _reflection.GeneratedProtocolMessageType('BIOSInfo', (_message.Message,), {
  'DESCRIPTOR' : _BIOSINFO,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.BIOSInfo)
  })
_sym_db.RegisterMessage(BIOSInfo)

SystemInfo = _reflection.GeneratedProtocolMessageType('SystemInfo', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMINFO,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.SystemInfo)
  })
_sym_db.RegisterMessage(SystemInfo)

ChassisInfo = _reflection.GeneratedProtocolMessageType('ChassisInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHASSISINFO,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.ChassisInfo)
  })
_sym_db.RegisterMessage(ChassisInfo)

BaseboardInfo = _reflection.GeneratedProtocolMessageType('BaseboardInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASEBOARDINFO,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.BaseboardInfo)
  })
_sym_db.RegisterMessage(BaseboardInfo)

CPUInfo = _reflection.GeneratedProtocolMessageType('CPUInfo', (_message.Message,), {
  'DESCRIPTOR' : _CPUINFO,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.CPUInfo)
  })
_sym_db.RegisterMessage(CPUInfo)

MemoryInfo = _reflection.GeneratedProtocolMessageType('MemoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYINFO,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.MemoryInfo)
  })
_sym_db.RegisterMessage(MemoryInfo)

DeviceInfo = _reflection.GeneratedProtocolMessageType('DeviceInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEINFO,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.DeviceInfo)
  })
_sym_db.RegisterMessage(DeviceInfo)

InventoryGetRequest = _reflection.GeneratedProtocolMessageType('InventoryGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYGETREQUEST,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.InventoryGetRequest)
  })
_sym_db.RegisterMessage(InventoryGetRequest)

InventoryGetResponse = _reflection.GeneratedProtocolMessageType('InventoryGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYGETRESPONSE,
  '__module__' : 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.inventory.v1.InventoryGetResponse)
  })
_sym_db.RegisterMessage(InventoryGetResponse)

_INVENTORYSVC = DESCRIPTOR.services_by_name['InventorySvc']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024opi_api.inventory.v1B\016InventoryProtoP\001Z.github.com/opiproject/opi-api/common/v1/gen/go'
  _BIOSINFO._serialized_start=41
  _BIOSINFO._serialized_end=98
  _SYSTEMINFO._serialized_start=100
  _SYSTEMINFO._serialized_end=225
  _CHASSISINFO._serialized_start=228
  _CHASSISINFO._serialized_end=356
  _BASEBOARDINFO._serialized_start=358
  _BASEBOARDINFO._serialized_end=465
  _CPUINFO._serialized_start=467
  _CPUINFO._serialized_end=520
  _MEMORYINFO._serialized_start=522
  _MEMORYINFO._serialized_end=592
  _DEVICEINFO._serialized_start=595
  _DEVICEINFO._serialized_end=786
  _INVENTORYGETREQUEST._serialized_start=788
  _INVENTORYGETREQUEST._serialized_end=809
  _INVENTORYGETRESPONSE._serialized_start=812
  _INVENTORYGETRESPONSE._serialized_end=1189
  _INVENTORYSVC._serialized_start=1191
  _INVENTORYSVC._serialized_end=1310
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import frontend_nvme_pcie_pb2 as frontend__nvme__pcie__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class FrontendNvmeServiceStub(object):
    """Front End (host-facing) APIs. Mostly used for NVMe/PCIe emulation and host presentation.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateNVMeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/CreateNVMeSubsystem',
                request_serializer=frontend__nvme__pcie__pb2.CreateNVMeSubsystemRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeSubsystem.FromString,
                )
        self.DeleteNVMeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/DeleteNVMeSubsystem',
                request_serializer=frontend__nvme__pcie__pb2.DeleteNVMeSubsystemRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNVMeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/UpdateNVMeSubsystem',
                request_serializer=frontend__nvme__pcie__pb2.UpdateNVMeSubsystemRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeSubsystem.FromString,
                )
        self.ListNVMeSubsystems = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/ListNVMeSubsystems',
                request_serializer=frontend__nvme__pcie__pb2.ListNVMeSubsystemsRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.ListNVMeSubsystemsResponse.FromString,
                )
        self.GetNVMeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/GetNVMeSubsystem',
                request_serializer=frontend__nvme__pcie__pb2.GetNVMeSubsystemRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeSubsystem.FromString,
                )
        self.NVMeSubsystemStats = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/NVMeSubsystemStats',
                request_serializer=frontend__nvme__pcie__pb2.NVMeSubsystemStatsRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeSubsystemStatsResponse.FromString,
                )
        self.CreateNVMeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/CreateNVMeController',
                request_serializer=frontend__nvme__pcie__pb2.CreateNVMeControllerRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeController.FromString,
                )
        self.DeleteNVMeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/DeleteNVMeController',
                request_serializer=frontend__nvme__pcie__pb2.DeleteNVMeControllerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNVMeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/UpdateNVMeController',
                request_serializer=frontend__nvme__pcie__pb2.UpdateNVMeControllerRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeController.FromString,
                )
        self.ListNVMeControllers = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/ListNVMeControllers',
                request_serializer=frontend__nvme__pcie__pb2.ListNVMeControllersRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.ListNVMeControllersResponse.FromString,
                )
        self.GetNVMeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/GetNVMeController',
                request_serializer=frontend__nvme__pcie__pb2.GetNVMeControllerRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeController.FromString,
                )
        self.NVMeControllerStats = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/NVMeControllerStats',
                request_serializer=frontend__nvme__pcie__pb2.NVMeControllerStatsRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeControllerStatsResponse.FromString,
                )
        self.CreateNVMeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/CreateNVMeNamespace',
                request_serializer=frontend__nvme__pcie__pb2.CreateNVMeNamespaceRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeNamespace.FromString,
                )
        self.DeleteNVMeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/DeleteNVMeNamespace',
                request_serializer=frontend__nvme__pcie__pb2.DeleteNVMeNamespaceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNVMeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/UpdateNVMeNamespace',
                request_serializer=frontend__nvme__pcie__pb2.UpdateNVMeNamespaceRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeNamespace.FromString,
                )
        self.ListNVMeNamespaces = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/ListNVMeNamespaces',
                request_serializer=frontend__nvme__pcie__pb2.ListNVMeNamespacesRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.ListNVMeNamespacesResponse.FromString,
                )
        self.GetNVMeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/GetNVMeNamespace',
                request_serializer=frontend__nvme__pcie__pb2.GetNVMeNamespaceRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeNamespace.FromString,
                )
        self.NVMeNamespaceStats = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/NVMeNamespaceStats',
                request_serializer=frontend__nvme__pcie__pb2.NVMeNamespaceStatsRequest.SerializeToString,
                response_deserializer=frontend__nvme__pcie__pb2.NVMeNamespaceStatsResponse.FromString,
                )


class FrontendNvmeServiceServicer(object):
    """Front End (host-facing) APIs. Mostly used for NVMe/PCIe emulation and host presentation.
    """

    def CreateNVMeSubsystem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNVMeSubsystem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNVMeSubsystem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNVMeSubsystems(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNVMeSubsystem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NVMeSubsystemStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNVMeController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNVMeController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNVMeController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNVMeControllers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNVMeController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NVMeControllerStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNVMeNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNVMeNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNVMeNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNVMeNamespaces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNVMeNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NVMeNamespaceStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FrontendNvmeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateNVMeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNVMeSubsystem,
                    request_deserializer=frontend__nvme__pcie__pb2.CreateNVMeSubsystemRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeSubsystem.SerializeToString,
            ),
            'DeleteNVMeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNVMeSubsystem,
                    request_deserializer=frontend__nvme__pcie__pb2.DeleteNVMeSubsystemRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNVMeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNVMeSubsystem,
                    request_deserializer=frontend__nvme__pcie__pb2.UpdateNVMeSubsystemRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeSubsystem.SerializeToString,
            ),
            'ListNVMeSubsystems': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNVMeSubsystems,
                    request_deserializer=frontend__nvme__pcie__pb2.ListNVMeSubsystemsRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.ListNVMeSubsystemsResponse.SerializeToString,
            ),
            'GetNVMeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNVMeSubsystem,
                    request_deserializer=frontend__nvme__pcie__pb2.GetNVMeSubsystemRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeSubsystem.SerializeToString,
            ),
            'NVMeSubsystemStats': grpc.unary_unary_rpc_method_handler(
                    servicer.NVMeSubsystemStats,
                    request_deserializer=frontend__nvme__pcie__pb2.NVMeSubsystemStatsRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeSubsystemStatsResponse.SerializeToString,
            ),
            'CreateNVMeController': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNVMeController,
                    request_deserializer=frontend__nvme__pcie__pb2.CreateNVMeControllerRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeController.SerializeToString,
            ),
            'DeleteNVMeController': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNVMeController,
                    request_deserializer=frontend__nvme__pcie__pb2.DeleteNVMeControllerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNVMeController': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNVMeController,
                    request_deserializer=frontend__nvme__pcie__pb2.UpdateNVMeControllerRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeController.SerializeToString,
            ),
            'ListNVMeControllers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNVMeControllers,
                    request_deserializer=frontend__nvme__pcie__pb2.ListNVMeControllersRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.ListNVMeControllersResponse.SerializeToString,
            ),
            'GetNVMeController': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNVMeController,
                    request_deserializer=frontend__nvme__pcie__pb2.GetNVMeControllerRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeController.SerializeToString,
            ),
            'NVMeControllerStats': grpc.unary_unary_rpc_method_handler(
                    servicer.NVMeControllerStats,
                    request_deserializer=frontend__nvme__pcie__pb2.NVMeControllerStatsRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeControllerStatsResponse.SerializeToString,
            ),
            'CreateNVMeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNVMeNamespace,
                    request_deserializer=frontend__nvme__pcie__pb2.CreateNVMeNamespaceRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeNamespace.SerializeToString,
            ),
            'DeleteNVMeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNVMeNamespace,
                    request_deserializer=frontend__nvme__pcie__pb2.DeleteNVMeNamespaceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNVMeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNVMeNamespace,
                    request_deserializer=frontend__nvme__pcie__pb2.UpdateNVMeNamespaceRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeNamespace.SerializeToString,
            ),
            'ListNVMeNamespaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNVMeNamespaces,
                    request_deserializer=frontend__nvme__pcie__pb2.ListNVMeNamespacesRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.ListNVMeNamespacesResponse.SerializeToString,
            ),
            'GetNVMeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNVMeNamespace,
                    request_deserializer=frontend__nvme__pcie__pb2.GetNVMeNamespaceRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeNamespace.SerializeToString,
            ),
            'NVMeNamespaceStats': grpc.unary_unary_rpc_method_handler(
                    servicer.NVMeNamespaceStats,
                    request_deserializer=frontend__nvme__pcie__pb2.NVMeNamespaceStatsRequest.FromString,
                    response_serializer=frontend__nvme__pcie__pb2.NVMeNamespaceStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.FrontendNvmeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FrontendNvmeService(object):
    """Front End (host-facing) APIs. Mostly used for NVMe/PCIe emulation and host presentation.
    """

    @staticmethod
    def CreateNVMeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/CreateNVMeSubsystem',
            frontend__nvme__pcie__pb2.CreateNVMeSubsystemRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeSubsystem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNVMeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/DeleteNVMeSubsystem',
            frontend__nvme__pcie__pb2.DeleteNVMeSubsystemRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNVMeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/UpdateNVMeSubsystem',
            frontend__nvme__pcie__pb2.UpdateNVMeSubsystemRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeSubsystem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNVMeSubsystems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/ListNVMeSubsystems',
            frontend__nvme__pcie__pb2.ListNVMeSubsystemsRequest.SerializeToString,
            frontend__nvme__pcie__pb2.ListNVMeSubsystemsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNVMeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/GetNVMeSubsystem',
            frontend__nvme__pcie__pb2.GetNVMeSubsystemRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeSubsystem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NVMeSubsystemStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/NVMeSubsystemStats',
            frontend__nvme__pcie__pb2.NVMeSubsystemStatsRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeSubsystemStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNVMeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/CreateNVMeController',
            frontend__nvme__pcie__pb2.CreateNVMeControllerRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNVMeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/DeleteNVMeController',
            frontend__nvme__pcie__pb2.DeleteNVMeControllerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNVMeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/UpdateNVMeController',
            frontend__nvme__pcie__pb2.UpdateNVMeControllerRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNVMeControllers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/ListNVMeControllers',
            frontend__nvme__pcie__pb2.ListNVMeControllersRequest.SerializeToString,
            frontend__nvme__pcie__pb2.ListNVMeControllersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNVMeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/GetNVMeController',
            frontend__nvme__pcie__pb2.GetNVMeControllerRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NVMeControllerStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/NVMeControllerStats',
            frontend__nvme__pcie__pb2.NVMeControllerStatsRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeControllerStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNVMeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/CreateNVMeNamespace',
            frontend__nvme__pcie__pb2.CreateNVMeNamespaceRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeNamespace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNVMeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/DeleteNVMeNamespace',
            frontend__nvme__pcie__pb2.DeleteNVMeNamespaceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNVMeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/UpdateNVMeNamespace',
            frontend__nvme__pcie__pb2.UpdateNVMeNamespaceRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeNamespace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNVMeNamespaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/ListNVMeNamespaces',
            frontend__nvme__pcie__pb2.ListNVMeNamespacesRequest.SerializeToString,
            frontend__nvme__pcie__pb2.ListNVMeNamespacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNVMeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/GetNVMeNamespace',
            frontend__nvme__pcie__pb2.GetNVMeNamespaceRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeNamespace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NVMeNamespaceStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/NVMeNamespaceStats',
            frontend__nvme__pcie__pb2.NVMeNamespaceStatsRequest.SerializeToString,
            frontend__nvme__pcie__pb2.NVMeNamespaceStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: uuid.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuuid.proto\x12\x11opi_api.common.v1\"\x15\n\x04Uuid\x12\r\n\x05value\x18\x01 \x01(\tBP\n\x11opi_api.common.v1B\tUuidProtoP\x01Z.github.com/opiproject/opi-api/common/v1/gen/gob\x06proto3')



_UUID = DESCRIPTOR.message_types_by_name['Uuid']
Uuid = _reflection.GeneratedProtocolMessageType('Uuid', (_message.Message,), {
  'DESCRIPTOR' : _UUID,
  '__module__' : 'uuid_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.common.v1.Uuid)
  })
_sym_db.RegisterMessage(Uuid)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021opi_api.common.v1B\tUuidProtoP\001Z.github.com/opiproject/opi-api/common/v1/gen/go'
  _UUID._serialized_start=33
  _UUID._serialized_end=54
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_aio.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import object_key_pb2 as object__key__pb2
import opicommon_pb2 as opicommon__pb2
import uuid_pb2 as uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x62\x61\x63kend_aio.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x10object_key.proto\x1a\x0fopicommon.proto\x1a\nuuid.proto\"\xa0\x01\n\rAioController\x12,\n\x06handle\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x12\n\nblock_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x62locks_count\x18\x03 \x01(\x03\x12%\n\x04uuid\x18\x04 \x01(\x0b\x32\x17.opi_api.common.v1.Uuid\x12\x10\n\x08\x66ilename\x18\x05 \x01(\t\"\xb1\x01\n\x1a\x43reateAioControllerRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/AioController\x12>\n\x0e\x61io_controller\x18\x02 \x01(\x0b\x32!.opi_api.storage.v1.AioControllerB\x03\xe0\x41\x02\x12\x19\n\x11\x61io_controller_id\x18\x03 \x01(\t\"T\n\x1a\x44\x65leteAioControllerRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/AioController\"\x88\x01\n\x1aUpdateAioControllerRequest\x12\x39\n\x0e\x61io_controller\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.AioController\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"|\n\x19ListAioControllersRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/AioController\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"q\n\x1aListAioControllersResponse\x12:\n\x0f\x61io_controllers\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.AioController\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x17GetAioControllerRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/AioController\"I\n\x19\x41ioControllerStatsRequest\x12,\n\x06handle\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"z\n\x1a\x41ioControllerStatsResponse\x12,\n\x06handle\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats2\xe2\x07\n\x14\x41ioControllerService\x12\xc3\x01\n\x13\x43reateAioController\x12..opi_api.storage.v1.CreateAioControllerRequest\x1a!.opi_api.storage.v1.AioController\"Y\x82\xd3\xe4\x93\x02)\"\x17/v1/{parent=subsystems}:\x0e\x61io_controller\xda\x41\'parent,aio_controller,aio_controller_id\x12\x8f\x01\n\x13\x44\x65leteAioController\x12..opi_api.storage.v1.DeleteAioControllerRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02#*!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12\xc3\x01\n\x13UpdateAioController\x12..opi_api.storage.v1.UpdateAioControllerRequest\x1a!.opi_api.storage.v1.AioController\"Y\x82\xd3\xe4\x93\x02\x36\x32$/v1/{aio_controller.name=subsystems}:\x0e\x61io_controller\xda\x41\x1a\x61io_controller,update_mask\x12\x9d\x01\n\x12ListAioControllers\x12-.opi_api.storage.v1.ListAioControllersRequest\x1a..opi_api.storage.v1.ListAioControllersResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x94\x01\n\x10GetAioController\x12+.opi_api.storage.v1.GetAioControllerRequest\x1a!.opi_api.storage.v1.AioController\"0\x82\xd3\xe4\x93\x02#\x12!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12u\n\x12\x41ioControllerStats\x12-.opi_api.storage.v1.AioControllerStatsRequest\x1a..opi_api.storage.v1.AioControllerStatsResponse\"\x00\x42^\n\x12opi_api.storage.v1B\x0f\x42\x61\x63kendAioProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')



_AIOCONTROLLER = DESCRIPTOR.message_types_by_name['AioController']
_CREATEAIOCONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['CreateAioControllerRequest']
_DELETEAIOCONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['DeleteAioControllerRequest']
_UPDATEAIOCONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['UpdateAioControllerRequest']
_LISTAIOCONTROLLERSREQUEST = DESCRIPTOR.message_types_by_name['ListAioControllersRequest']
_LISTAIOCONTROLLERSRESPONSE = DESCRIPTOR.message_types_by_name['ListAioControllersResponse']
_GETAIOCONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['GetAioControllerRequest']
_AIOCONTROLLERSTATSREQUEST = DESCRIPTOR.message_types_by_name['AioControllerStatsRequest']
_AIOCONTROLLERSTATSRESPONSE = DESCRIPTOR.message_types_by_name['AioControllerStatsResponse']
AioController = _reflection.GeneratedProtocolMessageType('AioController', (_message.Message,), {
  'DESCRIPTOR' : _AIOCONTROLLER,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.AioController)
  })
_sym_db.RegisterMessage(AioController)

CreateAioControllerRequest = _reflection.GeneratedProtocolMessageType('CreateAioControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAIOCONTROLLERREQUEST,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateAioControllerRequest)
  })
_sym_db.RegisterMessage(CreateAioControllerRequest)

DeleteAioControllerRequest = _reflection.GeneratedProtocolMessageType('DeleteAioControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAIOCONTROLLERREQUEST,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteAioControllerRequest)
  })
_sym_db.RegisterMessage(DeleteAioControllerRequest)

UpdateAioControllerRequest = _reflection.GeneratedProtocolMessageType('UpdateAioControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAIOCONTROLLERREQUEST,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateAioControllerRequest)
  })
_sym_db.RegisterMessage(UpdateAioControllerRequest)

ListAioControllersRequest = _reflection.GeneratedProtocolMessageType('ListAioControllersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAIOCONTROLLERSREQUEST,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListAioControllersRequest)
  })
_sym_db.RegisterMessage(ListAioControllersRequest)

ListAioControllersResponse = _reflection.GeneratedProtocolMessageType('ListAioControllersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAIOCONTROLLERSRESPONSE,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListAioControllersResponse)
  })
_sym_db.RegisterMessage(ListAioControllersResponse)

GetAioControllerRequest = _reflection.GeneratedProtocolMessageType('GetAioControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAIOCONTROLLERREQUEST,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetAioControllerRequest)
  })
_sym_db.RegisterMessage(GetAioControllerRequest)

AioControllerStatsRequest = _reflection.GeneratedProtocolMessageType('AioControllerStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _AIOCONTROLLERSTATSREQUEST,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.AioControllerStatsRequest)
  })
_sym_db.RegisterMessage(AioControllerStatsRequest)

AioControllerStatsResponse = _reflection.GeneratedProtocolMessageType('AioControllerStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _AIOCONTROLLERSTATSRESPONSE,
  '__module__' : 'backend_aio_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.AioControllerStatsResponse)
  })
_sym_db.RegisterMessage(AioControllerStatsResponse)

_AIOCONTROLLERSERVICE = DESCRIPTOR.services_by_name['AioControllerService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\017BackendAioProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _CREATEAIOCONTROLLERREQUEST.fields_by_name['parent']._options = None
  _CREATEAIOCONTROLLERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/AioController'
  _CREATEAIOCONTROLLERREQUEST.fields_by_name['aio_controller']._options = None
  _CREATEAIOCONTROLLERREQUEST.fields_by_name['aio_controller']._serialized_options = b'\340A\002'
  _DELETEAIOCONTROLLERREQUEST.fields_by_name['name']._options = None
  _DELETEAIOCONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/AioController'
  _LISTAIOCONTROLLERSREQUEST.fields_by_name['parent']._options = None
  _LISTAIOCONTROLLERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/AioController'
  _GETAIOCONTROLLERREQUEST.fields_by_name['name']._options = None
  _GETAIOCONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/AioController'
  _AIOCONTROLLERSERVICE.methods_by_name['CreateAioController']._options = None
  _AIOCONTROLLERSERVICE.methods_by_name['CreateAioController']._serialized_options = b'\202\323\344\223\002)\"\027/v1/{parent=subsystems}:\016aio_controller\332A\'parent,aio_controller,aio_controller_id'
  _AIOCONTROLLERSERVICE.methods_by_name['DeleteAioController']._options = None
  _AIOCONTROLLERSERVICE.methods_by_name['DeleteAioController']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _AIOCONTROLLERSERVICE.methods_by_name['UpdateAioController']._options = None
  _AIOCONTROLLERSERVICE.methods_by_name['UpdateAioController']._serialized_options = b'\202\323\344\223\00262$/v1/{aio_controller.name=subsystems}:\016aio_controller\332A\032aio_controller,update_mask'
  _AIOCONTROLLERSERVICE.methods_by_name['ListAioControllers']._options = None
  _AIOCONTROLLERSERVICE.methods_by_name['ListAioControllers']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _AIOCONTROLLERSERVICE.methods_by_name['GetAioController']._options = None
  _AIOCONTROLLERSERVICE.methods_by_name['GetAioController']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _AIOCONTROLLER._serialized_start=267
  _AIOCONTROLLER._serialized_end=427
  _CREATEAIOCONTROLLERREQUEST._serialized_start=430
  _CREATEAIOCONTROLLERREQUEST._serialized_end=607
  _DELETEAIOCONTROLLERREQUEST._serialized_start=609
  _DELETEAIOCONTROLLERREQUEST._serialized_end=693
  _UPDATEAIOCONTROLLERREQUEST._serialized_start=696
  _UPDATEAIOCONTROLLERREQUEST._serialized_end=832
  _LISTAIOCONTROLLERSREQUEST._serialized_start=834
  _LISTAIOCONTROLLERSREQUEST._serialized_end=958
  _LISTAIOCONTROLLERSRESPONSE._serialized_start=960
  _LISTAIOCONTROLLERSRESPONSE._serialized_end=1073
  _GETAIOCONTROLLERREQUEST._serialized_start=1075
  _GETAIOCONTROLLERREQUEST._serialized_end=1156
  _AIOCONTROLLERSTATSREQUEST._serialized_start=1158
  _AIOCONTROLLERSTATSREQUEST._serialized_end=1231
  _AIOCONTROLLERSTATSRESPONSE._serialized_start=1233
  _AIOCONTROLLERSTATSRESPONSE._serialized_end=1355
  _AIOCONTROLLERSERVICE._serialized_start=1358
  _AIOCONTROLLERSERVICE._serialized_end=2352
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_virtio_blk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
import object_key_pb2 as object__key__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x66rontend_virtio_blk.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x10object_key.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\xac\x01\n\tVirtioBlk\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x30\n\x07pcie_id\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpoint\x12/\n\tvolume_id\x18\x03 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x12\n\nmax_io_qps\x18\x04 \x01(\x03\"\x9d\x01\n\x16\x43reateVirtioBlkRequest\x12\x34\n\x06parent\x18\x01 \x01(\tB$\xe0\x41\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/VirtioBlk\x12\x36\n\nvirtio_blk\x18\x02 \x01(\x0b\x32\x1d.opi_api.storage.v1.VirtioBlkB\x03\xe0\x41\x02\x12\x15\n\rvirtio_blk_id\x18\x03 \x01(\t\"L\n\x16\x44\x65leteVirtioBlkRequest\x12\x32\n\x04name\x18\x01 \x01(\tB$\xe0\x41\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/VirtioBlk\"|\n\x16UpdateVirtioBlkRequest\x12\x31\n\nvirtio_blk\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.VirtioBlk\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"t\n\x15ListVirtioBlksRequest\x12\x34\n\x06parent\x18\x01 \x01(\tB$\xe0\x41\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/VirtioBlk\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"e\n\x16ListVirtioBlksResponse\x12\x32\n\x0bvirtio_blks\x18\x01 \x03(\x0b\x32\x1d.opi_api.storage.v1.VirtioBlk\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"I\n\x13GetVirtioBlkRequest\x12\x32\n\x04name\x18\x01 \x01(\tB$\xe0\x41\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/VirtioBlk\"L\n\x15VirtioBlkStatsRequest\x12\x33\n\rcontroller_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"r\n\x16VirtioBlkStatsResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats2\x8a\x07\n\x18\x46rontendVirtioBlkService\x12\xab\x01\n\x0f\x43reateVirtioBlk\x12*.opi_api.storage.v1.CreateVirtioBlkRequest\x1a\x1d.opi_api.storage.v1.VirtioBlk\"M\x82\xd3\xe4\x93\x02%\"\x17/v1/{parent=subsystems}:\nvirtio_blk\xda\x41\x1fparent,virtio_blk,virtio_blk_id\x12\x87\x01\n\x0f\x44\x65leteVirtioBlk\x12*.opi_api.storage.v1.DeleteVirtioBlkRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02#*!/v1/{name=virtioblks}/{virtioblk}\xda\x41\x04name\x12\xab\x01\n\x0fUpdateVirtioBlk\x12*.opi_api.storage.v1.UpdateVirtioBlkRequest\x1a\x1d.opi_api.storage.v1.VirtioBlk\"M\x82\xd3\xe4\x93\x02.2 /v1/{virtio_blk.name=subsystems}:\nvirtio_blk\xda\x41\x16virtio_blk,update_mask\x12\x91\x01\n\x0eListVirtioBlks\x12).opi_api.storage.v1.ListVirtioBlksRequest\x1a*.opi_api.storage.v1.ListVirtioBlksResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x88\x01\n\x0cGetVirtioBlk\x12\'.opi_api.storage.v1.GetVirtioBlkRequest\x1a\x1d.opi_api.storage.v1.VirtioBlk\"0\x82\xd3\xe4\x93\x02#\x12!/v1/{name=subsystems}/{virtioblk}\xda\x41\x04name\x12i\n\x0eVirtioBlkStats\x12).opi_api.storage.v1.VirtioBlkStatsRequest\x1a*.opi_api.storage.v1.VirtioBlkStatsResponse\"\x00\x42\x65\n\x12opi_api.storage.v1B\x16\x46rontendVirtioBlkProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')



_VIRTIOBLK = DESCRIPTOR.message_types_by_name['VirtioBlk']
_CREATEVIRTIOBLKREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtioBlkRequest']
_DELETEVIRTIOBLKREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtioBlkRequest']
_UPDATEVIRTIOBLKREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtioBlkRequest']
_LISTVIRTIOBLKSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtioBlksRequest']
_LISTVIRTIOBLKSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtioBlksResponse']
_GETVIRTIOBLKREQUEST = DESCRIPTOR.message_types_by_name['GetVirtioBlkRequest']
_VIRTIOBLKSTATSREQUEST = DESCRIPTOR.message_types_by_name['VirtioBlkStatsRequest']
_VIRTIOBLKSTATSRESPONSE = DESCRIPTOR.message_types_by_name['VirtioBlkStatsResponse']
VirtioBlk = _reflection.GeneratedProtocolMessageType('VirtioBlk', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOBLK,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioBlk)
  })
_sym_db.RegisterMessage(VirtioBlk)

CreateVirtioBlkRequest = _reflection.GeneratedProtocolMessageType('CreateVirtioBlkRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTIOBLKREQUEST,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateVirtioBlkRequest)
  })
_sym_db.RegisterMessage(CreateVirtioBlkRequest)

DeleteVirtioBlkRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtioBlkRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTIOBLKREQUEST,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteVirtioBlkRequest)
  })
_sym_db.RegisterMessage(DeleteVirtioBlkRequest)

UpdateVirtioBlkRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtioBlkRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTIOBLKREQUEST,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateVirtioBlkRequest)
  })
_sym_db.RegisterMessage(UpdateVirtioBlkRequest)

ListVirtioBlksRequest = _reflection.GeneratedProtocolMessageType('ListVirtioBlksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTIOBLKSREQUEST,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListVirtioBlksRequest)
  })
_sym_db.RegisterMessage(ListVirtioBlksRequest)

ListVirtioBlksResponse = _reflection.GeneratedProtocolMessageType('ListVirtioBlksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTIOBLKSRESPONSE,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListVirtioBlksResponse)
  })
_sym_db.RegisterMessage(ListVirtioBlksResponse)

GetVirtioBlkRequest = _reflection.GeneratedProtocolMessageType('GetVirtioBlkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTIOBLKREQUEST,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetVirtioBlkRequest)
  })
_sym_db.RegisterMessage(GetVirtioBlkRequest)

VirtioBlkStatsRequest = _reflection.GeneratedProtocolMessageType('VirtioBlkStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOBLKSTATSREQUEST,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioBlkStatsRequest)
  })
_sym_db.RegisterMessage(VirtioBlkStatsRequest)

VirtioBlkStatsResponse = _reflection.GeneratedProtocolMessageType('VirtioBlkStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOBLKSTATSRESPONSE,
  '__module__' : 'frontend_virtio_blk_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioBlkStatsResponse)
  })
_sym_db.RegisterMessage(VirtioBlkStatsResponse)

_FRONTENDVIRTIOBLKSERVICE = DESCRIPTOR.services_by_name['FrontendVirtioBlkService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\026FrontendVirtioBlkProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _CREATEVIRTIOBLKREQUEST.fields_by_name['parent']._options = None
  _CREATEVIRTIOBLKREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\036\n\034opi_api.storage.v1/VirtioBlk'
  _CREATEVIRTIOBLKREQUEST.fields_by_name['virtio_blk']._options = None
  _CREATEVIRTIOBLKREQUEST.fields_by_name['virtio_blk']._serialized_options = b'\340A\002'
  _DELETEVIRTIOBLKREQUEST.fields_by_name['name']._options = None
  _DELETEVIRTIOBLKREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\036\n\034opi_api.storage.v1/VirtioBlk'
  _LISTVIRTIOBLKSREQUEST.fields_by_name['parent']._options = None
  _LISTVIRTIOBLKSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\036\n\034opi_api.storage.v1/VirtioBlk'
  _GETVIRTIOBLKREQUEST.fields_by_name['name']._options = None
  _GETVIRTIOBLKREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\036\n\034opi_api.storage.v1/VirtioBlk'
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['CreateVirtioBlk']._options = None
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['CreateVirtioBlk']._serialized_options = b'\202\323\344\223\002%\"\027/v1/{parent=subsystems}:\nvirtio_blk\332A\037parent,virtio_blk,virtio_blk_id'
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['DeleteVirtioBlk']._options = None
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['DeleteVirtioBlk']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=virtioblks}/{virtioblk}\332A\004name'
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['UpdateVirtioBlk']._options = None
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['UpdateVirtioBlk']._serialized_options = b'\202\323\344\223\002.2 /v1/{virtio_blk.name=subsystems}:\nvirtio_blk\332A\026virtio_blk,update_mask'
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['ListVirtioBlks']._options = None
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['ListVirtioBlks']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['GetVirtioBlk']._options = None
  _FRONTENDVIRTIOBLKSERVICE.methods_by_name['GetVirtioBlk']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=subsystems}/{virtioblk}\332A\004name'
  _VIRTIOBLK._serialized_start=263
  _VIRTIOBLK._serialized_end=435
  _CREATEVIRTIOBLKREQUEST._serialized_start=438
  _CREATEVIRTIOBLKREQUEST._serialized_end=595
  _DELETEVIRTIOBLKREQUEST._serialized_start=597
  _DELETEVIRTIOBLKREQUEST._serialized_end=673
  _UPDATEVIRTIOBLKREQUEST._serialized_start=675
  _UPDATEVIRTIOBLKREQUEST._serialized_end=799
  _LISTVIRTIOBLKSREQUEST._serialized_start=801
  _LISTVIRTIOBLKSREQUEST._serialized_end=917
  _LISTVIRTIOBLKSRESPONSE._serialized_start=919
  _LISTVIRTIOBLKSRESPONSE._serialized_end=1020
  _GETVIRTIOBLKREQUEST._serialized_start=1022
  _GETVIRTIOBLKREQUEST._serialized_end=1095
  _VIRTIOBLKSTATSREQUEST._serialized_start=1097
  _VIRTIOBLKSTATSREQUEST._serialized_end=1173
  _VIRTIOBLKSTATSRESPONSE._serialized_start=1175
  _VIRTIOBLKSTATSRESPONSE._serialized_end=1289
  _FRONTENDVIRTIOBLKSERVICE._serialized_start=1292
  _FRONTENDVIRTIOBLKSERVICE._serialized_end=2198
# @@protoc_insertion_point(module_scope)



"""Console script for pydpu."""
import click

from .inventory import get_inventory
from .ipsec import create_new_tunnel, get_stats
from .storage import (
    create_nvme_controller,
    create_nvme_namespace,
    create_nvme_subsystem,
    list_nvme_subsystems,
)


@click.group()
@click.version_option(None, "-V", "--version")
@click.option("--address", help="IP address of the DPU gRPC management.", required=True)
@click.pass_context
def main(ctx, address):
    # ensure that ctx.obj exists and is a dict (in case `cli()` is called
    # by means other than the `if` block below)
    ctx.ensure_object(dict)
    ctx.obj["ADDRESS"] = address


@main.group()
@click.pass_context
def inventory(ctx):
    pass  # pragma: no cover


@inventory.command()
@click.pass_context
def get(ctx):
    get_inventory(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@main.group()
@click.pass_context
def ipsec(ctx):
    pass  # pragma: no cover


@ipsec.command()
@click.pass_context
def create_tunnel(ctx, **kwargs):
    create_new_tunnel(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@ipsec.command()
@click.pass_context
def stats(ctx, **kwargs):
    get_stats(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@main.group()
@click.pass_context
def storage(ctx):
    pass  # pragma: no cover


@storage.command()
@click.pass_context
def list(ctx, **kwargs):
    list_nvme_subsystems(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@storage.command()
@click.pass_context
def subsystem(ctx, **kwargs):
    create_nvme_subsystem(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@storage.command()
@click.pass_context
def controller(ctx, **kwargs):
    create_nvme_controller(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@storage.command()
@click.pass_context
def namespace(ctx, **kwargs):
    create_nvme_namespace(ctx.obj["ADDRESS"])
    click.echo("work in progress")


if __name__ == "__main__":
    main()  # pragma: no cover



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opicommon.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fopicommon.proto\x12\x12opi_api.storage.v1\"S\n\x0bPciEndpoint\x12\x0f\n\x07port_id\x18\x01 \x01(\x05\x12\x19\n\x11physical_function\x18\x02 \x01(\x05\x12\x18\n\x10virtual_function\x18\x03 \x01(\x05\"\xfd\x01\n\x0bVolumeStats\x12\x18\n\x10read_bytes_count\x18\x01 \x01(\x05\x12\x16\n\x0eread_ops_count\x18\x02 \x01(\x05\x12\x19\n\x11write_bytes_count\x18\x03 \x01(\x05\x12\x17\n\x0fwrite_ops_count\x18\x04 \x01(\x05\x12\x19\n\x11unmap_bytes_count\x18\x05 \x01(\x05\x12\x17\n\x0funmap_ops_count\x18\x06 \x01(\x05\x12\x1a\n\x12read_latency_ticks\x18\x07 \x01(\x05\x12\x1b\n\x13write_latency_ticks\x18\x08 \x01(\x05\x12\x1b\n\x13unmap_latency_ticks\x18\t \x01(\x05*\xf7\x01\n\x0e\x45ncryptionType\x12\x1f\n\x1b\x45NCRYPTION_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_128\x10\x01\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_192\x10\x02\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_256\x10\x03\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_128\x10\x04\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_192\x10\x05\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_256\x10\x06\x42]\n\x12opi_api.storage.v1B\x0eOpiCommonProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_ENCRYPTIONTYPE = DESCRIPTOR.enum_types_by_name['EncryptionType']
EncryptionType = enum_type_wrapper.EnumTypeWrapper(_ENCRYPTIONTYPE)
ENCRYPTION_TYPE_UNSPECIFIED = 0
ENCRYPTION_TYPE_AES_CBC_128 = 1
ENCRYPTION_TYPE_AES_CBC_192 = 2
ENCRYPTION_TYPE_AES_CBC_256 = 3
ENCRYPTION_TYPE_AES_XTS_128 = 4
ENCRYPTION_TYPE_AES_XTS_192 = 5
ENCRYPTION_TYPE_AES_XTS_256 = 6


_PCIENDPOINT = DESCRIPTOR.message_types_by_name['PciEndpoint']
_VOLUMESTATS = DESCRIPTOR.message_types_by_name['VolumeStats']
PciEndpoint = _reflection.GeneratedProtocolMessageType('PciEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _PCIENDPOINT,
  '__module__' : 'opicommon_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.PciEndpoint)
  })
_sym_db.RegisterMessage(PciEndpoint)

VolumeStats = _reflection.GeneratedProtocolMessageType('VolumeStats', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMESTATS,
  '__module__' : 'opicommon_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VolumeStats)
  })
_sym_db.RegisterMessage(VolumeStats)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\016OpiCommonProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _ENCRYPTIONTYPE._serialized_start=381
  _ENCRYPTIONTYPE._serialized_end=628
  _PCIENDPOINT._serialized_start=39
  _PCIENDPOINT._serialized_end=122
  _VOLUMESTATS._serialized_start=125
  _VOLUMESTATS._serialized_end=378
# @@protoc_insertion_point(module_scope)
